@@ -38,6 +38,7 @@ from gpt_index.indices.vector_store import (
 
 # langchain helper
 from gpt_index.langchain_helpers.chain_wrapper import LLMPredictor
+from gpt_index.langchain_helpers.memory_wrapper import GPTIndexMemory
 from gpt_index.langchain_helpers.sql_wrapper import SQLDatabase
 
 # prompts
@@ -62,18 +63,21 @@ from gpt_index.readers import (
     GoogleDocsReader,
     NotionPageReader,
     PineconeReader,
+    RssReader,
     SimpleDirectoryReader,
     SimpleMongoReader,
     SimpleWebPageReader,
     SlackReader,
     StringIterableReader,
     TrafilaturaWebReader,
+    TwitterTweetReader,
     WeaviateReader,
     WikipediaReader,
 )
 
 # token predictor
 from gpt_index.token_counter.mock_chain_wrapper import MockLLMPredictor
+from gpt_index.token_counter.mock_embed_model import MockEmbedding
 
 __all__ = [
     "GPTKeywordTableIndex",
@@ -110,14 +114,18 @@ __all__ = [
     "PineconeReader",
     "DiscordReader",
     "SimpleWebPageReader",
+    "RssReader",
     "BeautifulSoupWebReader",
     "TrafilaturaWebReader",
     "LLMPredictor",
     "MockLLMPredictor",
+    "MockEmbedding",
     "SQLDatabase",
+    "GPTIndexMemory",
     "SQLContextBuilder",
     "PromptHelper",
     "QueryConfig",
     "QueryMode",
     "IndexStructType",
+    "TwitterTweetReader",
 ]
