@@ -57,15 +57,16 @@ class Node(IndexStruct):
     def get_text(self) -> str:
         """Get text."""
         text = super().get_text()
-        if self.extra_info is not None:
-            extra_info_str = "\n".join(
-                [f"{k}: {str(v)}" for k, v in self.extra_info.items()]
-            )
-        else:
-            extra_info_str = None
-        result_text = text if extra_info_str is None else f"{extra_info_str}\n\n{text}"
+        result_text = (
+            text if self.extra_info_str is None else f"{self.extra_info_str}\n\n{text}"
+        )
         return result_text
 
+    def get_type(self) -> str:
+        """Get type."""
+        # TODO: consolidate with IndexStructType
+        return "node"
+
 
 @dataclass
 class IndexGraph(IndexStruct):
@@ -99,6 +100,10 @@ class IndexGraph(IndexStruct):
 
         self.all_nodes[node.index] = node
 
+    def get_type(self) -> str:
+        """Get type."""
+        return "tree"
+
 
 @dataclass
 class KeywordTable(IndexStruct):
@@ -142,6 +147,10 @@ class KeywordTable(IndexStruct):
         """Get the size of the table."""
         return len(self.table)
 
+    def get_type(self) -> str:
+        """Get type."""
+        return "keyword_table"
+
 
 @dataclass
 class IndexList(IndexStruct):
@@ -154,6 +163,10 @@ class IndexList(IndexStruct):
         # don't worry about child indices for now, nodes are all in order
         self.nodes.append(node)
 
+    def get_type(self) -> str:
+        """Get type."""
+        return "list"
+
 
 @dataclass
 class BaseIndexDict(IndexStruct):
@@ -199,6 +212,10 @@ class BaseIndexDict(IndexStruct):
         """Get node."""
         return self.get_nodes([text_id])[0]
 
+    def get_type(self) -> str:
+        """Get type."""
+        return "dict"
+
 
 # TODO: this should be specific to FAISS
 @dataclass
@@ -209,6 +226,10 @@ class IndexDict(BaseIndexDict):
 
     """
 
+    def get_type(self) -> str:
+        """Get type."""
+        return "dict"
+
 
 @dataclass
 class SimpleIndexDict(BaseIndexDict):
@@ -229,6 +250,10 @@ class SimpleIndexDict(BaseIndexDict):
             raise ValueError("text_id must be a string.")
         self.embedding_dict[text_id] = embedding
 
+    def get_type(self) -> str:
+        """Get type."""
+        return "simple_dict"
+
 
 @dataclass
 class WeaviateIndexStruct(IndexStruct):
@@ -252,6 +277,10 @@ class WeaviateIndexStruct(IndexStruct):
             raise ValueError("class_prefix must be provided.")
         return self.class_prefix
 
+    def get_type(self) -> str:
+        """Get type."""
+        return "weaviate"
+
 
 @dataclass
 class PineconeIndexStruct(IndexStruct):
@@ -260,3 +289,7 @@ class PineconeIndexStruct(IndexStruct):
     Docs are stored in Pinecone directly.
 
     """
+
+    def get_type(self) -> str:
+        """Get type."""
+        return "pinecone"
