@@ -16,16 +16,17 @@ from typing import (
 
 from gpt_index.data_structs.data_structs import IndexStruct, Node
 from gpt_index.data_structs.struct_type import IndexStructType
+from gpt_index.docstore import DocumentStore
 from gpt_index.embeddings.base import BaseEmbedding
 from gpt_index.embeddings.openai import OpenAIEmbedding
+from gpt_index.indices.node_utils import get_nodes_from_document
 from gpt_index.indices.prompt_helper import PromptHelper
 from gpt_index.indices.query.query_runner import QueryRunner
 from gpt_index.indices.query.schema import QueryConfig, QueryMode
-from gpt_index.indices.utils import truncate_text
 from gpt_index.langchain_helpers.chain_wrapper import LLMPredictor
 from gpt_index.langchain_helpers.text_splitter import TokenTextSplitter
 from gpt_index.response.schema import Response
-from gpt_index.schema import BaseDocument, DocumentStore
+from gpt_index.schema import BaseDocument
 from gpt_index.token_counter.token_counter import llm_token_counter
 
 IS = TypeVar("IS", bound=IndexStruct)
@@ -193,29 +194,12 @@ class BaseGPTIndex(Generic[IS]):
         text_splitter: TokenTextSplitter,
         start_idx: int = 0,
     ) -> List[Node]:
-        """Add document to index."""
-        text_chunks = text_splitter.split_text(document.get_text())
-        nodes = []
-        index_counter = 0
-        for i, text_chunk in enumerate(text_chunks):
-            fmt_text_chunk = truncate_text(text_chunk, 50)
-            print(f"> Adding chunk: {fmt_text_chunk}")
-            index_pos_info = {
-                "start": index_counter,  # NOTE: start is inclusive
-                "end": index_counter + len(text_chunk),  # NOTE: end is exclusive
-            }
-            index_counter += len(text_chunk) + 1
-            # if embedding specified in document, pass it to the Node
-            node = Node(
-                text=text_chunk,
-                index=start_idx + i,
-                ref_doc_id=document.get_doc_id(),
-                embedding=document.embedding,
-                extra_info=document.extra_info if self._include_extra_info else None,
-                node_info=index_pos_info,
-            )
-            nodes.append(node)
-        return nodes
+        return get_nodes_from_document(
+            document=document,
+            text_splitter=text_splitter,
+            start_idx=start_idx,
+            include_extra_info=self._include_extra_info,
+        )
 
     @abstractmethod
     def _build_index_from_documents(
@@ -367,7 +351,7 @@ class BaseGPTIndex(Generic[IS]):
         with open(save_path, "r") as f:
             result_dict = json.load(f)
             index_struct = cls.index_struct_cls.from_dict(result_dict["index_struct"])
-            docstore = DocumentStore.from_dict(result_dict["docstore"])
+            docstore = DocumentStore.load_from_dict(result_dict["docstore"])
             return cls(index_struct=index_struct, docstore=docstore, **kwargs)
 
     def save_to_disk(self, save_path: str, **save_kwargs: Any) -> None:
@@ -381,7 +365,7 @@ class BaseGPTIndex(Generic[IS]):
         """
         out_dict: Dict[str, dict] = {
             "index_struct": self.index_struct.to_dict(),
-            "docstore": self.docstore.to_dict(),
+            "docstore": self.docstore.serialize_to_dict(),
         }
         with open(save_path, "w") as f:
             json.dump(out_dict, f)
