@@ -100,6 +100,8 @@ class RefinePrompt(Prompt):
 
     """
 
+    # TODO: rename context_msg to context_str
+
     prompt_type: PromptType = PromptType.REFINE
     input_variables: List[str] = ["query_str", "existing_answer", "context_msg"]
 
@@ -155,3 +157,83 @@ class QueryKeywordExtractPrompt(Prompt):
 
     prompt_type: PromptType = PromptType.QUERY_KEYWORD_EXTRACT
     input_variables: List[str] = ["question", "max_keywords"]
+
+
+class SchemaExtractPrompt(Prompt):
+    """Schema extract prompt.
+
+    Prompt to extract schema from unstructured text `text`.
+
+    Required template variables: `text`, `schema`
+
+    Args:
+        template (str): Template for the prompt.
+        **prompt_kwargs: Keyword arguments for the prompt.
+
+    """
+
+    prompt_type: PromptType = PromptType.SCHEMA_EXTRACT
+    input_variables: List[str] = ["text", "schema"]
+
+
+class TextToSQLPrompt(Prompt):
+    """Text to SQL prompt.
+
+    Prompt to translate a natural language query into SQL,
+    given a schema `schema`.
+
+    Required template variables: `query_str`, `schema`
+
+    Args:
+        template (str): Template for the prompt.
+        **prompt_kwargs: Keyword arguments for the prompt.
+
+    """
+
+    prompt_type: PromptType = PromptType.TEXT_TO_SQL
+    input_variables: List[str] = ["query_str", "schema"]
+
+
+class TableContextPrompt(Prompt):
+    """Table context prompt.
+
+    Prompt to generate a table context given a table schema `schema`,
+    as well as unstructured text context `context_str`, and
+    a task `query_str`.
+    This includes both a high-level description of the table
+    as well as a description of each column in the table.
+
+    Args:
+        template (str): Template for the prompt.
+        **prompt_kwargs: Keyword arguments for the prompt.
+
+    """
+
+    prompt_type: PromptType = PromptType.TABLE_CONTEXT
+    input_variables: List[str] = ["schema", "context_str", "query_str"]
+
+
+class RefineTableContextPrompt(Prompt):
+    """Refine Table context prompt.
+
+    Prompt to refine a table context given a table schema `schema`,
+    as well as unstructured text context `context_msg`, and
+    a task `query_str`.
+    This includes both a high-level description of the table
+    as well as a description of each column in the table.
+
+    Args:
+        template (str): Template for the prompt.
+        **prompt_kwargs: Keyword arguments for the prompt.
+
+    """
+
+    # TODO: rename context_msg to context_str
+
+    prompt_type: PromptType = PromptType.TABLE_CONTEXT
+    input_variables: List[str] = [
+        "schema",
+        "context_msg",
+        "query_str",
+        "existing_answer",
+    ]
