@@ -23,9 +23,11 @@ from gpt_index.readers.pinecone import PineconeReader
 from gpt_index.readers.schema.base import Document
 from gpt_index.readers.slack import SlackReader
 from gpt_index.readers.string_iterable import StringIterableReader
+from gpt_index.readers.twitter import TwitterTweetReader
 from gpt_index.readers.weaviate.reader import WeaviateReader
 from gpt_index.readers.web import (
     BeautifulSoupWebReader,
+    RssReader,
     SimpleWebPageReader,
     TrafilaturaWebReader,
 )
@@ -49,5 +51,7 @@ __all__ = [
     "SimpleWebPageReader",
     "BeautifulSoupWebReader",
     "TrafilaturaWebReader",
+    "RssReader",
     "MakeWrapper",
+    "TwitterTweetReader",
 ]
