@@ -1,15 +1,21 @@
 """Test list index."""
 
-from typing import Any, Dict, List, Tuple
+from typing import Any, Dict, List, Optional, Tuple
 from unittest.mock import patch
 
 import pytest
 
 from gpt_index.data_structs.data_structs import Node
 from gpt_index.indices.list.base import GPTListIndex
+from gpt_index.indices.prompt_helper import PromptHelper
 from gpt_index.indices.query.list.embedding_query import GPTListIndexEmbeddingQuery
+from gpt_index.langchain_helpers.chain_wrapper import LLMPredictor
+from gpt_index.langchain_helpers.text_splitter import TokenTextSplitter
+from gpt_index.prompts.base import Prompt
 from gpt_index.readers.schema.base import Document
+from gpt_index.utils import globals_helper
 from tests.mock_utils.mock_decorator import patch_common
+from tests.mock_utils.mock_predict import mock_llmpredictor_predict
 from tests.mock_utils.mock_prompts import MOCK_REFINE_PROMPT, MOCK_TEXT_QA_PROMPT
 
 
@@ -44,7 +50,8 @@ def test_build_list(
     _mock_init: Any,
     _mock_predict: Any,
     _mock_total_tokens_used: Any,
-    _mock_splitter: Any,
+    _mock_split_text_overlap: Any,
+    _mock_split_text: Any,
     documents: List[Document],
 ) -> None:
     """Test build list."""
@@ -62,7 +69,8 @@ def test_build_list_multiple(
     _mock_init: Any,
     _mock_predict: Any,
     _mock_total_tokens_used: Any,
-    _mock_splitter: Any,
+    _mock_split_text_overlap: Any,
+    _mock_split_text: Any,
 ) -> None:
     """Test build list multiple."""
     documents = [
@@ -83,7 +91,8 @@ def test_list_insert(
     _mock_init: Any,
     _mock_predict: Any,
     _mock_total_tokens_used: Any,
-    _mock_splitter: Any,
+    _mock_split_text_overlap: Any,
+    _mock_split_text: Any,
     documents: List[Document],
 ) -> None:
     """Test insert to list."""
@@ -111,7 +120,8 @@ def test_list_delete(
     _mock_init: Any,
     _mock_predict: Any,
     _mock_total_tokens_used: Any,
-    _mock_splitter: Any,
+    _mock_split_text_overlap: Any,
+    _mock_split_text: Any,
     documents: List[Document],
 ) -> None:
     """Test insert to list and then delete."""
@@ -169,6 +179,7 @@ def test_query(
     _mock_init: Any,
     _mock_predict: Any,
     _mock_total_tokens_used: Any,
+    _mock_split_text_overlap: Any,
     _mock_split_text: Any,
     documents: List[Document],
     struct_kwargs: Dict,
@@ -187,11 +198,72 @@ def test_query(
     assert node_info["end"] == 12
 
 
+@patch.object(LLMPredictor, "total_tokens_used", return_value=0)
+@patch.object(LLMPredictor, "predict", side_effect=mock_llmpredictor_predict)
+@patch.object(LLMPredictor, "__init__", return_value=None)
+def test_index_overlap(
+    _mock_init: Any,
+    _mock_predict: Any,
+    _mock_total_tokens_used: Any,
+    struct_kwargs: Dict,
+) -> None:
+    """Test node info calculation with overlapping node text."""
+    index_kwargs, query_kwargs = struct_kwargs
+
+    documents = [
+        Document(
+            "Hello world. This is a test 1. This is a test 2."
+            + " This is a test 3. This is a test 4. This is a test 5.\n"
+        )
+    ]
+
+    def _mock_text_splitter_with_space(
+        prompt: Prompt, num_chunks: int, padding: Optional[int] = 1
+    ) -> TokenTextSplitter:
+        """Mock text splitter."""
+        return TokenTextSplitter(
+            separator=" ",
+            chunk_size=30,
+            chunk_overlap=10,
+            tokenizer=globals_helper.tokenizer,
+        )
+
+    with patch.object(
+        PromptHelper,
+        "get_text_splitter_given_prompt",
+        side_effect=_mock_text_splitter_with_space,
+    ):
+
+        index = GPTListIndex(documents, **index_kwargs)
+
+        query_str = "What is?"
+        response = index.query(query_str, mode="default", **query_kwargs)
+        node_info_0 = (
+            response.source_nodes[0].node_info
+            if response.source_nodes[0].node_info
+            else {}
+        )
+        # First chunk: 'Hello world. This is a test 1. This is a test 2.
+        # This is a test 3. This is a test 4. This is a'
+        assert node_info_0["start"] == 0  # start at the start
+        assert node_info_0["end"] == 94  # Length of first chunk.
+
+        node_info_1 = (
+            response.source_nodes[1].node_info
+            if response.source_nodes[1].node_info
+            else {}
+        )
+        # Second chunk: 'This is a test 4. This is a test 5.\n'
+        assert node_info_1["start"] == 67  # Position of second chunk relative to start
+        assert node_info_1["end"] == 103  # End index
+
+
 @patch_common
 def test_query_with_keywords(
     _mock_init: Any,
     _mock_predict: Any,
     _mock_total_tokens_used: Any,
+    _mock_split_text_overlap: Any,
     _mock_split_text: Any,
     documents: List[Document],
     struct_kwargs: Dict,
@@ -222,6 +294,7 @@ def test_embedding_query(
     _mock_init: Any,
     _mock_predict: Any,
     _mock_total_tokens_used: Any,
+    _mock_split_text_overlap: Any,
     _mock_split_text: Any,
     documents: List[Document],
     struct_kwargs: Dict,
@@ -243,7 +316,8 @@ def test_extra_info(
     _mock_init: Any,
     _mock_predict: Any,
     _mock_total_tokens_used: Any,
-    _mock_splitter: Any,
+    _mock_split_text_overlap: Any,
+    _mock_split_text: Any,
     documents: List[Document],
 ) -> None:
     """Test build/query with extra info."""
@@ -262,21 +336,3 @@ def test_extra_info(
     assert list_index.index_struct.nodes[3].get_text() == (
         "extra_info: extra_info\n" "foo: bar\n\n" "This is a test v2."
     )
-
-
-@patch_common
-def test_node_indices(
-    _mock_init: Any,
-    _mock_predict: Any,
-    _mock_total_tokens_used: Any,
-    _mock_split_text: Any,
-    documents: List[Document],
-    struct_kwargs: Dict,
-) -> None:
-    """Test Node start and end indices info."""
-    index_kwargs, query_kwargs = struct_kwargs
-    index = GPTListIndex(documents, **index_kwargs)
-
-    assert index.index_struct.nodes[0].node_info == {"start": 0, "end": 12}
-    assert index.index_struct.nodes[1].node_info == {"start": 13, "end": 28}
-    assert index.index_struct.nodes[2].node_info == {"start": 29, "end": 50}
